@@ -26,7 +26,7 @@ FLAG_STRING = """ALL flags should be used as is (no '-' prefix)
     j    Print top of stack joined by newlines on end of execution
     L    Print top of stack joined by newlines (Vertically) on end of execution
     s    Sum/concatenate top of stack on end of execution
-    M    Make implicit range generation start at 0 instead of 1
+    M    Make implicit range generation and while loop counter start at 0 instead of 1
     m    Make implicit range generation end at n-1 instead of n
     Ṁ    Equivalent to having both m and M flags
     v    Use Vyxal encoding for input file
@@ -95,9 +95,6 @@ def execute_vyxal(file_name, flags, inputs, output_var=None, online_mode=False):
     else:
         inputs = list(map(lambda x: vy_eval(x, ctx), inputs))
 
-    if "a" in flags:  # All inputs as array
-        inputs = [inputs]
-
     if "H" in flags:  # Pre-initalise stack to 100
         stack = [100]
     else:
@@ -126,6 +123,7 @@ def execute_vyxal(file_name, flags, inputs, output_var=None, online_mode=False):
     ctx.vyxal_lists = "P" not in flags
     ctx.print_decimals = "ḋ" in flags
     ctx.empty_input_is_zero = "?" not in flags
+    ctx.array_inputs = "a" in flags
 
     if "2" in flags:
         ctx.default_arity = 2
