@@ -32,7 +32,7 @@ STRUCTURE_INFORMATION = {
 
 CLOSING_CHARACTERS = "".join([v[1] for v in STRUCTURE_INFORMATION.values()])
 OPENING_CHARACTERS = "".join(STRUCTURE_INFORMATION.keys())
-MONADIC_MODIFIERS = list("v⁽&~ßƒɖ")
+MONADIC_MODIFIERS = list("v⁽&~ßƒɖ") + ["¨="]
 DYADIC_MODIFIERS = list("₌‡₍")
 TRIADIC_MODIFIERS = list("≬")
 # The modifiers are stored as lists to allow for potential digraph
